@@ -226,7 +226,7 @@ arv_uvcp_packet_debug (const ArvUvcpPacket *packet, ArvDebugLevel level)
 {
 	char *string;
 
-	if (!arv_debug_check (&arv_debug_category_cp, level))
+	if (!arv_debug_check (ARV_DEBUG_CATEGORY_CP, level))
 		return;
 
 	string = arv_uvcp_packet_to_string (packet);
