@@ -204,7 +204,8 @@ struct  _ArvViewer {
 	gboolean packet_resend;
 	guint packet_timeout;
 	guint frame_retention;
-	ArvRegisterCachePolicy cache_policy;
+	ArvRegisterCachePolicy register_cache_policy;
+	ArvRangeCheckPolicy range_check_policy;
 
 	gulong video_window_xid;
 };
@@ -226,7 +227,8 @@ arv_viewer_set_options (ArvViewer *viewer,
 			gboolean packet_resend,
 			guint packet_timeout,
 			guint frame_retention,
-			ArvRegisterCachePolicy cache_policy)
+			ArvRegisterCachePolicy register_cache_policy,
+			ArvRangeCheckPolicy range_check_policy)
 {
 	g_return_if_fail (viewer != NULL);
 
@@ -234,7 +236,8 @@ arv_viewer_set_options (ArvViewer *viewer,
 	viewer->packet_resend = packet_resend;
 	viewer->packet_timeout = packet_timeout;
 	viewer->frame_retention = frame_retention;
-	viewer->cache_policy = cache_policy;
+	viewer->register_cache_policy = register_cache_policy;
+	viewer->range_check_policy = range_check_policy;
 }
 
 static double
@@ -648,7 +651,7 @@ snapshot_cb (GtkButton *button, ArvViewer *viewer)
 	date_string = g_date_time_format (date, "%Y-%m-%d-%H:%M:%S");
 	filename = g_strdup_printf ("%s-%s-%d-%d-%s-%s.raw",
 				    arv_camera_get_vendor_name (viewer->camera, NULL),
-				    arv_camera_get_device_id (viewer->camera, NULL),
+				    arv_camera_get_device_serial_number (viewer->camera, NULL),
 				    width,
 				    height,
 				    pixel_format != NULL ? pixel_format : "Unknown",
@@ -1149,7 +1152,10 @@ start_camera (ArvViewer *viewer, const char *camera_id)
 	if (!ARV_IS_CAMERA (viewer->camera))
 		return FALSE;
 
-	arv_device_set_register_cache_policy (arv_camera_get_device (viewer->camera), viewer->cache_policy);
+	arv_device_set_register_cache_policy (arv_camera_get_device (viewer->camera),
+					      viewer->register_cache_policy);
+	arv_device_set_range_check_policy (arv_camera_get_device (viewer->camera),
+					   viewer->range_check_policy);
 
 	viewer->camera_name = g_strdup (camera_id);
 
@@ -1437,7 +1443,8 @@ arv_viewer_init (ArvViewer *viewer)
 	viewer->packet_resend = TRUE;
 	viewer->packet_timeout = 20;
 	viewer->frame_retention = 100;
-	viewer->cache_policy = ARV_REGISTER_CACHE_POLICY_DEFAULT;
+	viewer->register_cache_policy = ARV_REGISTER_CACHE_POLICY_DEFAULT;
+	viewer->range_check_policy = ARV_RANGE_CHECK_POLICY_DEFAULT;
 }
 
 static void
